# -*- coding: utf-8 -*-

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

__author__ = "Ildar Nikolaev"
__email__ = "nildar@users.sourceforge.net"

bl_info = {
    "name"			: "B-Maxwell",
    "description"	: "Maxwell Render integration",
    "author"		: "N.Ildar <nildar@users.sourceforge.net>",
    "version"		: (0, 9, 2),
    "blender"		: (2, 74, 0),
    "location"		: "Info header, render engine menu",
    "warning"		: "Use only with Blender version 2.74",
    "wiki_url"		: "http://sourceforge.net/p/bmaxwell/wiki/",
    "tracker_url"	: "https://sourceforge.net/p/bmaxwell/tickets/",
    "category"		: "Render"
}

import os
import bpy


class BMaxwellPreferences(bpy.types.AddonPreferences):
    bl_idname = __name__

    maxwell_path = bpy.props.StringProperty(
        name="Maxwell Render Location",
        description="Path there is Maxwell Render installed",
        default=os.environ.get("MAXWELL3_ROOT", "/Applications/Maxwell 3" if os.sys.platform == "darwin" else ""),
        subtype='DIR_PATH'
    )
    verbose_output = bpy.props.BoolProperty(
        name="Verbose",
        description="Verbose output to console",
        default=True
    )
    format_instances = bpy.props.StringProperty(
        name="Format string for names of instances",
        default="[I:{1:07}] {0}"
    )
    uvlayout_path = bpy.props.StringProperty(
        name="UVLayout Location",
        description="Path there is Headus UVLayout installed",
        subtype='DIR_PATH'
    )

    def draw(self, context):
        layout = self.layout
        layout.prop(self, "maxwell_path")
        layout.prop(self, "format_instances")
        layout.prop(self, "uvlayout_path")
        layout.prop(self, "verbose_output")

    @classmethod
    def get_preferences(cls):
        return bpy.context.user_preferences.addons[cls.bl_idname].preferences


def _bmaxwell_manual_map():
    if "manual" in globals():
        import importlib
        importlib.reload(manual)
    try:
        import inspect
        from .manual import special_map
        # brrrrr.......
        stack = inspect.stack()
        rna_id = stack[2][0].f_locals['rna_id']
        for m in special_map:
            if rna_id in m[0]:
                return m[1], (("*", m[2]), )
    except:
        pass
    from .manual import (url_manual_prefix, url_manual_mapping)
    return url_manual_prefix, url_manual_mapping


def register():
    bpy.utils.register_module(__name__)
    bpy.utils.register_manual_map(_bmaxwell_manual_map)


def unregister():
    bpy.utils.unregister_module(__name__)
    bpy.utils.unregister_manual_map(_bmaxwell_manual_map)


def _main():
    import importlib

    for m in (".engine", ".properties", ".operators", ".ui"):
        importlib.import_module(m, __name__)


_main()
del _main
