# -*- coding: utf-8 -*-

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

__author__ = "Ildar Nikolaev"
__email__ = "nildar@users.sourceforge.net"

from bpy.types import Operator
from bl_operators.presets import AddPresetBase


class Presets(AddPresetBase, Operator):
    """Add Maxwell Render Preset"""
    bl_idname = "maxwell.render_preset_add"
    bl_label = "Add Render Preset"

    preset_menu = "MAXWELL_MT_render_presets"
    preset_subdir = "bmaxwell/render"

    preset_defines = [
        "mx = bpy.context.scene.maxwell",
        "rp = mx.rp"
    ]

    preset_values = [
        "mx.run",
        "mx.cmdline",
        "rp.quality",
        "rp.threads",
        "rp.time",
        "rp.sl",
        "rp.multilight",
        "rp.separate",
        "rp.motionblur",
        "rp.mbsteps",
        "rp.displacement",
        "rp.dispersion",
        "rp.illumination",
        "rp.reflcaustics",
        "rp.refrcaustics",
        "rp.ovrmat",
        "rp.defmat",
        "rp.colorspace",
        "rp.gamma",
        "rp.burn",
        "rp.doSharpness",
        "rp.sharpness",
        "rp.doDiffraction",
        "rp.diffraction",
        "rp.frequency",
        "rp.aperture",
        "rp.obstacle",
        "rp.doScattering",
        "rp.scattering",
        "rp.doDevignetting",
        "rp.devignetting"
    ]


#
# Searching paths
#

class SearchingPathsAdd(Operator):
    bl_idname = "maxwell.add_searching_path"
    bl_label = "Add searching path"
    bl_description = "Add searching path"

    def execute(self, context):
        rp = context.scene.maxwell.rp
        paths = rp.searching_paths
        idx = len(paths)
        paths.add()
        rp.active_sp_index = idx
        return {'FINISHED'}


class SearchingPathsRemove(Operator):
    bl_idname = "maxwell.remove_searching_path"
    bl_label = "Remove searching path"
    bl_description = "Remove searching path"

    def execute(self, context):
        rp = context.scene.maxwell.rp
        paths = rp.searching_paths
        idx = rp.active_sp_index
        if idx >= 0:
            paths.remove(idx)
            max_idx = len(paths)
            if idx >= max_idx:
                rp.active_sp_index = max_idx - 1
        return {'FINISHED'}
