# -*- coding: utf-8 -*-

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

__author__ = "Ildar Nikolaev"
__email__ = "nildar@users.sourceforge.net"

from datetime import datetime

from bpy.types import Operator
from bl_operators.presets import AddPresetBase


class Environment(AddPresetBase, Operator):
    """Maxwell Environment Preset"""
    bl_idname = "maxwell.environment_preset_add"
    bl_label = "Add Environment Preset"

    preset_menu = "MAXWELL_MT_environment_presets"
    preset_subdir = "bmaxwell/environment"

    preset_defines = [
        "world = bpy.context.world",
        "world['maxwell'].clear()",
        "env = world.maxwell"
    ]

    preset_values = [
        "env.type",
        "env.sky",

        "env.constant.luminance",
        "env.constant.zenith",
        "env.constant.horizon",
        "env.constant.controlPoint",

        "env.physical.intensity",
        "env.physical.planetRefl",
        "env.physical.ozone",
        "env.physical.water",
        "env.physical.angstrom",
        "env.physical.wavelength",
        "env.physical.albedo",
        "env.physical.asymmetry",

        "env.sun.type",
        "env.sun.power",
        "env.sun.radius",
        "env.sun.temperature",
        "env.sun.color",
        "env.sun.position",
        "env.sun.latitude",
        "env.sun.longitude",
        "env.sun.date",
        "env.sun.time",
        "env.sun.sm",
        "env.sun.rotation",
        "env.sun.zenith",
        "env.sun.azimuth",
        "env.sun.direction",
        "env.sun.dir_object",

        "env.ibl.intensity",
        "env.ibl.interpolation",
        "env.ibl.screen_mapping",

        "env.ibl.background.type",
        "env.ibl.background.map",
        "env.ibl.background.intensity",
        "env.ibl.background.scale",
        "env.ibl.background.offset",

        "env.ibl.reflection.type",
        "env.ibl.reflection.map",
        "env.ibl.reflection.intensity",
        "env.ibl.reflection.scale",
        "env.ibl.reflection.offset",

        "env.ibl.refraction.type",
        "env.ibl.refraction.map",
        "env.ibl.refraction.intensity",
        "env.ibl.refraction.scale",
        "env.ibl.refraction.offset",

        "env.ibl.illumination.type",
        "env.ibl.illumination.map",
        "env.ibl.illumination.intensity",
        "env.ibl.illumination.scale",
        "env.ibl.illumination.offset"
    ]


class CurrentDateTime(Operator):
    bl_idname = "maxwell.datetime_now"
    bl_label = "Now"
    bl_description = "Sets the Date and Time to your computer's current date and time"

    def execute(self, context):
        sun = context.world.maxwell.sun
        now = datetime.now()
        sun.date = now.date().isoformat()
        sun.time = now.time().strftime("%H:%M:%S")
        sun.sm = int((now - datetime.utcnow()).total_seconds() / 3600)
        return {'FINISHED'}
