# -*- coding: utf-8 -*-

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

__author__ = "Ildar Nikolaev"
__email__ = "nildar@users.sourceforge.net"

from bpy.types import PropertyGroup, Camera
from bpy.props import (
    EnumProperty,
    FloatProperty,
    IntProperty,
    BoolProperty,
    PointerProperty
)


class MaxwellCameraProperties(PropertyGroup):
    shtype = EnumProperty(
        name="Shutter Units",
        items=[
            ('SPEED', "Shutter Speed", ""),
            ('ANGLE', "Shutter Angle", "")],
        default='SPEED'
    )
    shutter = FloatProperty(
        name="Shutter Speed",
        default=500.0,
        min=0.01, max=16000.0,
        soft_min=0.01, soft_max=16000.0,
        precision=3,
        step=100.0
    )
    rotary = FloatProperty(
        name="Shutter Angle",
        default=180.0,
        min=0.01, max=5000.0,
        soft_min=0.0, soft_max=5000.0,
        precision=3,
        step=100.0
    )
    iso = IntProperty(
        name="ISO",
        default=100,
        min=1, max=16000,
        soft_min=1, soft_max=16000
    )
    fstop = FloatProperty(
        name="f-Stop",
        default=8.0,
        min=1.0, max=100000.0,
        soft_min=1.0, soft_max=100000.0,
        precision=3,
        step=100.0
    )
    diaphragm = EnumProperty(
        name="Diaphragm",
        description="Controls the shape of the 'bokeh' effect",
        items=[
            ('CIRCULAR', "Circular", ""),
            ('POLYGONAL', "Polygonal", "")],
        default='CIRCULAR'
    )
    blades = IntProperty(
        name="Blades",
        description="Numbers of blades in the Polygonal diaphragm",
        default=6,
        min=3, max=96,
        soft_min=3, soft_max=96
    )
    angle = IntProperty(
        name="Angle",
        description="Rotation angle of aperture opening",
        default=60,
        min=0, max=720,
        soft_min=0, soft_max=720,
        subtype='UNSIGNED'
    )
    correction = BoolProperty(
        name="Focal Length Correction",
        description="Focal Length Need Correction",
        default=True
    )

    @classmethod
    def register(cls):
        Camera.maxwell = PointerProperty(type=cls)

    @classmethod
    def unregiser(cls):
        del Camera.maxwell
